==> cloudt-system-api-0.2.2-20230802.055433-1-sources.jar: com/elitescloud/cloudt/system/constant/MsgSendTypeEnum.java <==
package com.elitescloud.cloudt.system.constant;


import com.elitescloud.cloudt.system.vo.SysUdcVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 消息类型枚举
 * **/
public enum MsgSendTypeEnum {
    SYS_INTERIOR("SYS", "MsgSendType", "SYS_INTERIOR", "系统站内",1),
    EMAIL("SYS", "MsgSendType", "EMAIL", "邮件",2),
    //Low-Code Development Platform
    MOBILE_SMS("SYS", "MsgSendType", "MOBILE_SMS", "短信",3),
    MINI_PROGRAM("SYS", "MsgSendType", "MINI_PROGRAM", "小程序",4),

    OFFICIAL_ACCOUNT("SYS", "MsgSendType", "OFFICIAL_ACCOUNT", "公众号",5),

    APP("SYS", "MsgSendType", "APP", "原生APP",6),
    ;


    private final String domainCode;
    private final String udcCode;
    private final String udcName;
    private final String description;
    private final int sortNo;

    MsgSendTypeEnum(String domainCode, String udcCode, String udcName, String description, int sortNo) {
        this.domainCode = domainCode;
        this.sortNo = sortNo;
        this.udcCode = udcCode;
        this.udcName = udcName;
        this.description = description;
    }

    public String getDescription() {
        return description;
    }

    public SysUdcVO getUdcVO() {
        SysUdcVO sysUdcVO = new SysUdcVO();
        sysUdcVO.setDomainCode(this.domainCode);
        sysUdcVO.setUdcCode(this.udcCode);
        sysUdcVO.setUdcName(this.udcName);
        sysUdcVO.setUdcVal(this.name());
        sysUdcVO.setValDesc(this.description);
        sysUdcVO.setValSortNo(this.sortNo);
        sysUdcVO.setId((long) this.sortNo);
        return sysUdcVO;
    }
    public static List<SysUdcVO> getSysUdcVOList() {
        ArrayList<SysUdcVO> sysUdcVOList = new ArrayList<>();
        for (var ele : values()) {
            sysUdcVOList.add(ele.getUdcVO());
        }
        return sysUdcVOList;
    }
}

==> cloudt-system-api-0.2.9.1-20240422.034614-1-sources.jar: com/elitescloud/cloudt/system/constant/MsgSendTypeEnum.java <==
package com.elitescloud.cloudt.system.constant;


import com.elitescloud.cloudt.system.vo.SysUdcVO;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 消息类型枚举
 * **/
public enum MsgSendTypeEnum {
    SYS_INTERIOR("SYS", "MsgSendType", "SYS_INTERIOR", "系统站内",1),
    EMAIL("SYS", "MsgSendType", "EMAIL", "邮件",2),
    //Low-Code Development Platform
    MOBILE_SMS("SYS", "MsgSendType", "MOBILE_SMS", "短信",3),
    MINI_PROGRAM("SYS", "MsgSendType", "MINI_PROGRAM", "小程序",4),

    OFFICIAL_ACCOUNT("SYS", "MsgSendType", "OFFICIAL_ACCOUNT", "公众号",5),

    APP("SYS", "MsgSendType", "APP", "原生APP",6),
    WX_BOOT("SYS", "MsgSendType", "WX_BOOT", "企微机器人",7),
    ;


    private final String domainCode;
    private final String udcCode;
    private final String udcName;
    private final String description;
    private final int sortNo;

    MsgSendTypeEnum(String domainCode, String udcCode, String udcName, String description, int sortNo) {
        this.domainCode = domainCode;
        this.sortNo = sortNo;
        this.udcCode = udcCode;
        this.udcName = udcName;
        this.description = description;
    }

    public String getDescription() {
        return description;
    }

    public SysUdcVO getUdcVO() {
        SysUdcVO sysUdcVO = new SysUdcVO();
        sysUdcVO.setDomainCode(this.domainCode);
        sysUdcVO.setUdcCode(this.udcCode);
        sysUdcVO.setUdcName(this.udcName);
        sysUdcVO.setUdcVal(this.name());
        sysUdcVO.setValDesc(this.description);
        sysUdcVO.setValSortNo(this.sortNo);
        sysUdcVO.setId((long) this.sortNo);
        return sysUdcVO;
    }
    public static List<SysUdcVO> getSysUdcVOList() {
        ArrayList<SysUdcVO> sysUdcVOList = new ArrayList<>();
        for (var ele : values()) {
            sysUdcVOList.add(ele.getUdcVO());
        }
        return sysUdcVOList;
    }

    private static final Map<String, MsgSendTypeEnum> ALL = Arrays.stream(MsgSendTypeEnum.values())
            .collect(Collectors.toMap(MsgSendTypeEnum::name, t -> t, (t1, t2) -> t1));

    /**
     * 转换对象
     *
     * @param value
     * @return
     */
    public static MsgSendTypeEnum parse(String value) {
        return ALL.get(value);
    }
}
